import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/pdpa_repository.dart';
import 'package:pam_flutter/widgets/commons/loading_stack.dart';
import 'package:pam_flutter/widgets/commons/primary_button.dart';
import 'package:pam_flutter/widgets/consent_item.dart';

class ConsentPage extends StatefulWidget {
  final String consentId;
  final String baseAPI;

  ConsentPage({
    required this.consentId,
    required this.baseAPI,
  });

  @override
  State<StatefulWidget> createState() {
    return ConsentPageState();
  }
}

class ConsentPageState extends State<ConsentPage> {
  late PDPARepository pdpaRepository;

  @override
  void initState() {
    super.initState();

    this.pdpaRepository = PDPARepository(
      options: NewRepositoryOptions(
          baseUrl: "${widget.baseAPI}/pdpa/consent-message"),
    );
    this.pdpaRepository.get(widget.consentId);
  }

  @override
  void dispose() {
    super.dispose();

    this.pdpaRepository.dispose();
  }

  void Function(bool isAllow) onConsentAllowedChanged(String settingName) {
    return (bool isAllowed) {
      return this.pdpaRepository.allowConsentSetting(settingName, isAllowed);
    };
  }

  @override
  Widget build(BuildContext context) {
    bool isTablet = MediaQuery.of(context).size.width >= 768;

    return Scaffold(
      body: Container(
        alignment: Alignment.center,
        padding: EdgeInsets.only(
          top: MediaQuery.of(context).padding.top,
          bottom: MediaQuery.of(context).padding.bottom + 16,
          left: 16,
          right: 16,
        ),
        child: LoadingStack(
          isLoadingSC: this.pdpaRepository.isLoadingSC,
          children: () => [
            Column(
              children: [
                Container(
                  padding: EdgeInsets.only(
                    top: 16,
                    bottom: 16,
                  ),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Container(
                        child: Text(
                          this.pdpaRepository.data!.Name,
                          style: TextStyle(
                            color: this
                                .pdpaRepository
                                .data!
                                .StyleConfiguration
                                .ConsentDetail
                                .PrimaryColor,
                            fontSize: 32,
                            fontWeight: FontWeight.bold,
                          ),
                        ),
                      ),
                      Expanded(
                        child: Container(
                          padding: EdgeInsets.only(
                            left: 16,
                            right: 16,
                          ),
                          child: Text(
                            isTablet
                                ? this.pdpaRepository.data!.Description
                                : "",
                            style: TextStyle(fontSize: 18),
                          ),
                        ),
                      ),
                      Container(
                        width: 100,
                        child: Row(
                          children: [
                            Expanded(
                              child: Container(
                                alignment: Alignment.center,
                                decoration: BoxDecoration(
                                    color: Colors.white,
                                    borderRadius: BorderRadius.only(
                                      topLeft: Radius.circular(8),
                                      bottomLeft: Radius.circular(8),
                                    ),
                                    border: Border.all(
                                      color: this
                                          .pdpaRepository
                                          .data!
                                          .StyleConfiguration
                                          .ConsentDetail
                                          .PrimaryColor,
                                    )),
                                padding: EdgeInsets.only(
                                  top: 12,
                                  bottom: 12,
                                  left: 8,
                                  right: 8,
                                ),
                                child: Text(
                                  "TH",
                                  style: TextStyle(
                                    color: this
                                        .pdpaRepository
                                        .data!
                                        .StyleConfiguration
                                        .ConsentDetail
                                        .PrimaryColor,
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              ),
                            ),
                            Expanded(
                              child: Container(
                                alignment: Alignment.center,
                                decoration: BoxDecoration(
                                    color: Colors.grey.shade300,
                                    borderRadius: BorderRadius.only(
                                      topRight: Radius.circular(8),
                                      bottomRight: Radius.circular(8),
                                    ),
                                    border: Border.all(
                                      color: Colors.grey.shade300,
                                    )),
                                padding: EdgeInsets.only(
                                  top: 12,
                                  bottom: 12,
                                  left: 8,
                                  right: 8,
                                ),
                                child: Text(
                                  "EN",
                                  style: TextStyle(
                                    color: this
                                        .pdpaRepository
                                        .data!
                                        .StyleConfiguration
                                        .ConsentDetail
                                        .PrimaryColor,
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
                Container(
                  child: Text(
                    !isTablet ? this.pdpaRepository.data!.Description : "",
                    style: TextStyle(
                      fontSize: 18,
                      fontWeight: FontWeight.bold,
                    ),
                  ),
                ),
                Expanded(
                  child: Container(
                    margin: EdgeInsets.only(
                      top: 16,
                      bottom: 16,
                    ),
                    decoration: BoxDecoration(
                      border: Border.all(color: Colors.grey.shade400),
                      borderRadius: BorderRadius.circular(8),
                    ),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(8),
                      child: ListView(
                        padding: EdgeInsets.zero,
                        children: [
                          ConsentItem(
                            title: "Terms & Conditions",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .TermsAndConditions,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .terms_and_conditions),
                          ),
                          ConsentItem(
                            title: "Privacy Overview",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .PrivacyOverview,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .privacy_overview),
                          ),
                          ConsentItem(
                            title: "Necessary Cookies",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .NecessaryCookies,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .necessary_cookies),
                          ),
                          ConsentItem(
                            title: "Preferences Cookies",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .PreferencesCookies,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .preferences_cookies),
                          ),
                          ConsentItem(
                            title: "Analytics Cookies",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .AnalyticsCookies,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .analytics_cookies),
                          ),
                          ConsentItem(
                            title: "Marketing Cookies",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .MarketingCookies,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .marketing_cookies),
                          ),
                          ConsentItem(
                            title: "Social Media Cookies",
                            setting: this
                                .pdpaRepository
                                .data!
                                .Setting
                                .SocialMediaCookies,
                            onAllowed: this.onConsentAllowedChanged(
                                ConsentMessageSettingConsentDetails
                                    .social_media_cookies),
                          ),
                        ],
                      ),
                    ),
                  ),
                ),
                Container(
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      PrimaryButton(
                        onClick: () {},
                        title: "Save Setting",
                        textColor: Colors.white,
                        backgroundColor: this
                            .pdpaRepository
                            .data!
                            .StyleConfiguration
                            .ConsentDetail
                            .PrimaryColor,
                        margin: EdgeInsets.only(right: 12),
                      ),
                      PrimaryButton(
                        onClick: () {
                          this.pdpaRepository.allowAllConsentSetting();
                        },
                        title: "Accept All",
                        icon: Icons.check_circle,
                        textColor: Colors.white,
                        backgroundColor: this
                            .pdpaRepository
                            .data!
                            .StyleConfiguration
                            .ConsentDetail
                            .SecondaryColor,
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
