// ignore_for_file: non_constant_identifier_names

import 'dart:convert';
import 'package:http/http.dart';
import 'package:pam_flutter/models/consent_message_model.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/types.dart';
import 'package:pam_flutter/utils/requester.dart';

class ConsentMessageTypes {
  static String get tracking_type => "tracking_type";
  static String get contacting_type => "contacting_type";
}

class ConsentMessageSettingConsentDetails {
  ConsentMessageSettingConsentDetails._();

  static String get terms_and_conditions => "TermsAndConditions";

  static String get analytics_cookies => "AnalyticsCookies";

  static String get email => "Email";

  static String get facebook_messenger => "FacebookMessenger";

  static String get line => "Line";

  static String get marketing_cookies => "MarketingCookies";

  static String get mobile_notification => "MobileNotification";

  static String get necessary_cookies => "NecessaryCookies";

  static String get preferences_cookies => "PreferencesCookies";

  static String get privacy_overview => "PrivacyOverview";

  static String get sms => "SMS";

  static String get social_media_cookies => "SocialMediaCookies";
}

class PDPARepository extends BaseDataRepository<ConsentMessageModel> {
  final IRepositoryOptions options;

  PDPARepository({
    required this.options,
  }) : super(options);

  @override
  Future get(String id,
      {Map<String, dynamic>? params}) async {
    try {
      this.toLoadingStatus();
      late Map<String, dynamic> data;

      if (params == null) {
        params = {};
      }

      Response response =
      await Requester.get("${this.options.getBaseUrl()}/api/pdpa/consent-message/$id", params);
      Map<String, dynamic> js = json.decode(utf8.decode(response.bodyBytes));
      data = {
        "data": js
      };

      this.data = ConsentMessageModel.fromJson(data["data"]);
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.toErrorStatus(e);
    }
  }

  void allowConsentSetting(String settingName, bool isAllowed) {
    try {
      this.toLoadingStatus();

      switch (settingName) {
        case "TermsAndConditions":
          this.data?.Setting.TermsAndConditions.IsAllowed = isAllowed;
          break;
        case "AnalyticsCookies":
          this.data?.Setting.AnalyticsCookies.IsAllowed = isAllowed;
          break;
        case "Email":
          this.data?.Setting.Email.IsAllowed = isAllowed;
          break;
        case "FacebookMessenger":
          this.data?.Setting.FacebookMessenger.IsAllowed = isAllowed;
          break;
        case "Line":
          this.data?.Setting.Line.IsAllowed = isAllowed;
          break;
        case "MarketingCookies":
          this.data?.Setting.MarketingCookies.IsAllowed = isAllowed;
          break;
        case "MobileNotification":
          this.data?.Setting.MobileNotification.IsAllowed = isAllowed;
          break;
        case "NecessaryCookies":
          this.data?.Setting.NecessaryCookies.IsAllowed = isAllowed;
          break;
        case "PreferencesCookies":
          this.data?.Setting.PreferencesCookies.IsAllowed = isAllowed;
          break;
        case "PrivacyOverview":
          this.data?.Setting.PrivacyOverview.IsAllowed = isAllowed;
          break;
        case "SMS":
          this.data?.Setting.SMS.IsAllowed = isAllowed;
          break;
        case "SocialMediaCookies":
          this.data?.Setting.SocialMediaCookies.IsAllowed = isAllowed;
          break;
        default:
      }
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.toErrorStatus(e);
    }
  }

  void allowAllConsentSetting() {
    try {
      this.toLoadingStatus();

      this.data?.Setting.TermsAndConditions.IsAllowed = true;
      this.data?.Setting.AnalyticsCookies.IsAllowed = true;
      this.data?.Setting.Email.IsAllowed = true;
      this.data?.Setting.FacebookMessenger.IsAllowed = true;
      this.data?.Setting.Line.IsAllowed = true;
      this.data?.Setting.MarketingCookies.IsAllowed = true;
      this.data?.Setting.MobileNotification.IsAllowed = true;
      this.data?.Setting.NecessaryCookies.IsAllowed = true;
      this.data?.Setting.PreferencesCookies.IsAllowed = true;
      this.data?.Setting.PrivacyOverview.IsAllowed = true;
      this.data?.Setting.SMS.IsAllowed = true;
      this.data?.Setting.SocialMediaCookies.IsAllowed = true;
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.toErrorStatus(e);
    }
  }
}
